-- created December 2010 Thomas W. Stuetz
-- January 2011 Thomas W Stuetz  changed tablename prefixes
--                               new name sw_order --> sw_ordering
--                               added several columns


clear screen
set serveroutput on
/
drop table sw_customer cascade constraints purge;
drop table sw_product cascade constraints purge;
drop table sw_ordering cascade constraints purge;
drop table sw_item cascade constraints purge;
drop sequence sw_customer_seq;
drop sequence sw_product_seq;
drop sequence sw_ordering_seq;
drop sequence sw_item_seq;
create sequence sw_customer_seq start with 1;
create sequence sw_product_seq start with 51;
create sequence sw_ordering_seq start with 10283;
create sequence sw_item_seq start with 1;

create table sw_customer (
  CUST_ID           NUMBER(10) constraint sw_customer_pk primary key, 
  CUST_NAME         VARCHAR2(40 CHAR), 
  CUST_COUNTRY      VARCHAR2(40 CHAR),
  CUST_ABBR         VARCHAR2(5 CHAR),   -- ABBR --> ABBREVIATION ... Abkuerzung
  CUST_CCARD_NO     VARCHAR2(16 CHAR)   -- Kreditkartennummer
);

create table sw_product (
  prod_id           NUMBER(10) constraint sw_product_pk primary key,
  prod_name         VARCHAR2(40 CHAR),
  prod_unitprice    NUMBER(20,2),-- Preis / Stueck (Einheit)
  prod_unitsinstock NUMBER(10),  -- Waren auf Lager (Lagerstand)
  prod_unitsonorder NUMBER(10),  -- derzeit bestellte Waren
  prod_reorderlevel NUMBER(10),  -- Warenbestand, ab dem bestellt werden muss (Bestellpunkt)
  prod_discontinued NUMBER       -- Produkt wird nicht mehr weitergefuehrt
);

create table sw_ordering (
  ord_id            NUMBER(10) constraint sw_order_pk primary key,
  ord_cust_id       NUMBER(10),
  ord_orderdate     DATE,    -- Wann wurden die Waren bestellt
  ord_requireddate  DATE,    -- Wann benoetigt der Kunde die Waren
  ord_shippeddate   DATE,    -- Wann wurden die Waren versendet
  ord_freight       NUMBER(20,2),  -- Frachtgewicht
  constraint sw_ord_cust_fk foreign key (ord_cust_id) references sw_customer(cust_id)
);

create table sw_item (
  itm_id            NUMBER(10) constraint sw_item_pk primary key,
  itm_ord_id        NUMBER(10),
  itm_prod_id       NUMBER(10),
  itm_unitprice     NUMBER(20,2),
  itm_quantity      NUMBER(20,2),
  itm_discount      NUMBER(20,5),
  constraint sw_itm_prod_fk foreign key (itm_prod_id) references sw_product(prod_id),
  constraint sw_itm_ord_fk foreign key (itm_ord_id) references sw_ordering(ord_id)
);

insert into sw_customer (cust_id
                        ,cust_name
                        ,cust_country
                        ,cust_abbr)
select sw_customer_seq.nextval
      ,companyname
      ,country
      ,customerid 
from demo_nordwind.customers;

insert into sw_product (prod_id
                       ,prod_name
                       ,prod_unitprice
                       ,prod_unitsinstock
                       ,prod_unitsonorder
                       ,prod_reorderlevel
                       ,prod_discontinued)
select productid
      ,productname
      ,unitprice 
      ,unitsinstock
      ,unitsonorder
      ,reorderlevel
      ,discontinued
from demo_nordwind.products;

insert into sw_ordering (ord_id
                        ,ord_cust_id
                        ,ord_orderdate
                        ,ord_requireddate
                        ,ord_shippeddate
                        ,ord_freight
                        )
select orderid
      ,(select cust_id 
        from   sw_customer 
        where  cust_abbr = o.customerid)
      ,orderdate
      ,requireddate
      ,shippeddate
      ,freight
from DEMO_NORDWIND.orders o;

insert into sw_item (itm_id
                    ,itm_ord_id
                    ,itm_prod_id
                    ,itm_unitprice
                    ,itm_quantity
                    ,itm_discount)
select sw_item_seq.nextval
      ,orderid
      ,productid
      ,unitprice
      ,quantity
      ,discount
from DEMO_NORDWIND.order_details;

commit;
