package entity;

import java.io.Serializable;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedNativeQueries;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 *
 * @author java@htl-leonding
 */
@Entity
@Table(name = "SW_CUSTOMER")
@NamedQueries({
    @NamedQuery(name = "Customer.findAll", query = "SELECT c FROM Customer c"),
    @NamedQuery(name = "Customer.findById", query = "SELECT c FROM Customer c WHERE c.id = :custId"),
    @NamedQuery(name = "Customer.findByName", query = "SELECT c FROM Customer c WHERE c.name = :custName"),
    @NamedQuery(name = "Customer.findByCountry", query = "SELECT c FROM Customer c WHERE c.country = :custCountry"),
    @NamedQuery(name = "Customer.findByAbbr", query = "SELECT c FROM Customer c WHERE c.abbr = :custAbbr"),
    @NamedQuery(name = "Customer.findByCreditCardNo", query = "SELECT c FROM Customer c WHERE c.creditCardId = :custCreditCardId"),
    @NamedQuery(name = "Customer.findAllCountries", query = "SELECT c.country FROM Customer c GROUP BY c.country ORDER BY c.country")
})
public class Customer implements Serializable {
    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "CUST_ID")
    private Long id;
    @Column(name = "CUST_NAME")
    private String name;
    @Column(name = "CUST_COUNTRY")
    private String country;
    @Column(name = "CUST_ABBR")
    private String abbr;
    @Column(name = "CUST_CCARD_NO")
    private String creditCardId;
    @OneToMany(mappedBy = "customer")
    private List<Ordering> orderingList;

    public Customer() {
    }

    public String getAbbr() {
        return abbr;
    }

    public void setAbbr(String abbr) {
        this.abbr = abbr;
    }

    public String getCreditCardId() {
        return creditCardId;
    }

    public void setCreditCardId(String creditCardId) {
        this.creditCardId = creditCardId;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public List<Ordering> getOrderingList() {
        return orderingList;
    }

    public void setOrderingList(List<Ordering> orderingList) {
        this.orderingList = orderingList;
    }

   /**
     *
     * @param creditCardNo
     * @return true, falls Kreditkartennummer ungueltig
     */
    public static boolean checkCreditCardNo(String creditCardNo) {
        try {
            if (creditCardNo.length() != 16) {
                return false;
            }
            int odd = 0, even = 0;
            char[] ccNo = creditCardNo.toCharArray();
            for (int i = 0; i < ccNo.length - 1; i++) {
                if (i % 2 == 0) {
                    even += crossSum(2 * (ccNo[i] - '0'));
                    System.out.println("GERADE: " + (ccNo[i] - '0'));
                } else {
                    odd += ccNo[i] - '0';
                    System.out.println("UNGERADE: " + (ccNo[i] - '0'));
                }
            }
            int checkDigit = (10 - (even + odd) % 10) % 10;
            if (checkDigit == ccNo[15] - '0') {
                return true;
            } else {
                System.out.println("Kennziffer muesste sein: " + checkDigit);
                return false;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            return false;
        }
    }

    public static int crossSum(int number) {
        System.out.print("Ziffernsumme: " + number);
        int crossSum = 0;
        while (number > 0) {
            crossSum += number % 10;
            number /= 10;
        }
        System.out.println(" --> " + crossSum);
        return crossSum;
    }


    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Customer)) {
            return false;
        }
        Customer other = (Customer) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "Customer id=" + id + ": " + name;
    }

}
